///////////////////////////////////////////////////
// LED.h
// 720020-1175x
//
// Applied Data Systems
//
// The LED on the BitsyX is controlled by the LSB of the SUPPC2 register
// which is located at the physical address 0x08000018
// 
// This is a sample stream interface driver for controlling the LED on the
// ADS BitsyX system.  By using port name "LED1:" you can control the LED
//
// This driver has several features:
//  - The LED state can be set or read
//  - An IOCTL for starting/stopping a heartbeat (periodic blink)
//  - An IOCTL allowing you to "blink" any number, by counting LED flashes
//  - Easy driver initialization using regsvrce.exe (see notes in LED.CPP for details)
//
// Note: This driver only controls the LED on the BitsyX itself.  The LED on ADS
//       personality boards is a charge indicator for the battery charging circuit
//       and is not controllable from software.
//
//
// History
// -------
// 720020-11751: February 26, 2004 (ctacke)
//  - Initial implementation
///////////////////////////////////////////////////

#define DRIVER_NAME		_T("LedDriver")
#define DRIVER_LIBRARY	_T("led.dll")
#define DRIVER_PREFIX	_T("LED")
#define DRIVER_INDEX	1
#define DRIVER_ORDER	9

#define LED_ADDR_BASE	0x08000000
#define LED_ADDR_OFFSET	0x18
#define LED_MASK		0x00000001

#define IOCTL_LED_BLINK_NUMBER		1
#define IOCTL_LED_START_HEARTBEAT	2
#define IOCTL_LED_STOP_HEARTBEAT	3

struct BLINK_NUMBER_DATA
{
	BYTE	LEDIndex;
	DWORD	Number;
	WORD	InterDigitDelay;
	WORD	TerminateDelay;
};